# Generated by Django 4.0.6 on 2022-10-15 04:35

import ckeditor.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('jeral', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='GrupuBambu',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255, verbose_name='Naran Grupu')),
                ('naran_kordenador', models.CharField(blank=True, max_length=255, null=True, verbose_name='Naran Kordenador')),
                ('kordinate_centru', models.CharField(max_length=255)),
                ('kordinate_area', models.TextField(blank=True, null=True)),
                ('deskrisaun', ckeditor.fields.RichTextField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('imagen', models.ImageField(blank=True, default='grupubambu/default.png', null=True, upload_to='grupubambu/')),
                ('kontaktu', models.CharField(blank=True, max_length=255, null=True)),
                ('hashed', models.TextField()),
                ('suku', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='jeral.suku', verbose_name='Hili Suku')),
                ('user_created', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Hili User')),
            ],
            options={
                'verbose_name_plural': 'Grupu Bambu',
            },
        ),
        migrations.CreateModel(
            name='ImportasaunBambu',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data_importasaun', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('kuantidade', models.CharField(blank=True, max_length=200, null=True, verbose_name='Quantidade')),
                ('deskrisaun', ckeditor.fields.RichTextField(max_length=255, verbose_name='Deskrisaun')),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('hashed', models.TextField(blank=True, null=True)),
                ('grupubambu', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='mapa.grupubambu', verbose_name='Hili Grupu Bambu')),
                ('user_created', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Hili User')),
            ],
            options={
                'verbose_name_plural': 'Grupu Bambu',
            },
        ),
        migrations.CreateModel(
            name='GrupuViveirus',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255, verbose_name='Naran Grupu')),
                ('naran_kordenador', models.CharField(blank=True, max_length=255, null=True, verbose_name='Naran Kordenador')),
                ('kordinate_centru', models.CharField(max_length=255)),
                ('kordinate_area', models.TextField(blank=True, null=True)),
                ('deskrisaun', ckeditor.fields.RichTextField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('imagen', models.ImageField(blank=True, default='grupuviveirus/default.png', null=True, upload_to='grupuviveirus/')),
                ('kontaktu', models.CharField(blank=True, max_length=255, null=True)),
                ('hashed', models.TextField()),
                ('suku', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='jeral.suku', verbose_name='Hili Suku')),
                ('user_created', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User Kria')),
            ],
            options={
                'verbose_name_plural': 'Grupu Viveirus',
            },
        ),
        migrations.CreateModel(
            name='AreaBambu',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255)),
                ('naran_kordenador', models.CharField(blank=True, max_length=255, null=True, verbose_name='Naran Kordenador')),
                ('kordinate_centru', models.CharField(max_length=255)),
                ('hectar', models.CharField(blank=True, max_length=255, null=True, verbose_name='Hectar')),
                ('kordinate_area', models.TextField()),
                ('imagen', models.ImageField(blank=True, default='areabambu/default.png', null=True, upload_to='areabambu/')),
                ('kontaktu', models.CharField(blank=True, max_length=255, null=True)),
                ('deskrisaun', ckeditor.fields.RichTextField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('kor', models.CharField(blank=True, max_length=255, null=True)),
                ('hashed', models.TextField()),
                ('suku', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='jeral.suku', verbose_name='Hili Suku')),
                ('user_created', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User Kria')),
            ],
            options={
                'verbose_name_plural': 'Area Bambu',
            },
        ),
    ]



from django.shortcuts import render,redirect
from django.contrib.auth.decorators import login_required
# from population.models import Population,DetailFamily,Family,Religion,Profession,Citizen,Aldeia,Village,User,Migration,Death,Migrationout,Temporary,ChangeFamily
# from population.utils import getnewidp,getnewidf
# from population.forms import Family_form,Family_form,FamilyPosition,Population_form,DetailFamily_form,CustumDetailFamily_form,Death_form,Migration_form,Migrationout_form,Changefamily_form
from django.views.decorators.csrf import csrf_exempt
import json
from django.utils import timezone

from django.core.paginator import Paginator

# from mapa.forms import *
# from custom.utils import getnewid, getjustnewid, hash_md5, getlastid
from django.db.models import Count
from django.contrib import messages
from django.shortcuts import get_object_or_404
from django.db.models import Q
from datetime import date
from django.http import JsonResponse
# from employee.models import *
# from datetime import datetime, timedelta
# from vizitor.forms import CustomAuthenticationForm
from django.contrib.auth.views import LoginView
from django.contrib.auth import authenticate, login, logout

from django.contrib.auth.decorators import login_required

from mapa.models import *
from mapa.forms import *
from django.contrib.auth.models import User




from main.decorators import login_ona, seidauk_login, allowed_users



@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def grupuviveirus(request):

    buka = False;
    bukatitle = "mamuk"
    

    if request.GET.__contains__('page') :
        page_num = request.GET.get('page')
    else:
        page_num = 1
    if request.GET.__contains__('pesquiza'):
        buka = True
        paginator = Paginator(GrupuViveirus.objects.order_by('-id').filter(naran__icontains=request.GET['pesquiza']), 1)
    else:
        paginator = Paginator(GrupuViveirus.objects.order_by('-id'), 10)

    page_range = []
    for i in range(paginator.num_pages):
        page_range.append(i+1)
        data_GrupuViveirus = paginator.page(page_num)

        page_num_int = int(page_num)

    if buka :
        bukatitle = "Rezultadu Pesquiza husi <i>' (" + request.GET['pesquiza'] + ") '</i>"

    context = {
        "pajina_grupuviveirus" : "active",
        "grupuviveirus" : data_GrupuViveirus,
        'bukatitle' : bukatitle,
        'page_range' : page_range,
        'current_page' : page_num_int,
    }
    return render(request, 'mapa/grupuviveirus/lista.html',context)




@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def inputgrupuviveirus(request):



#     dokumentu =  Dokumentu.objects.all()
    # grupubambuform = GrupuBambuForm()


	# //prosses elemina sombolo no caracter nebe la inportante husi cordinate nebe foti husi lefleat draw

    # $data_cordinate = str_replace('LatLng(','[', substr($data_cordinate, 0, 10000));
    # $data_cordinate = str_replace(')',']', substr($data_cordinate, 0, 10000));	
    # $center_cordinate = str_replace('LatLng(','', substr($center_cordinate, 0, 100));
    # $center_cordinate = str_replace(')','', substr($center_cordinate, 0, 100));




    if request.method == 'POST':

        kordinatesarea = request.POST['kordinate_area']
        kordinatescentru = request.POST['kordinate_centru']

        data_cordinate_area = kordinatesarea.replace("LatLng(", "[")
        data_cordinate_area = data_cordinate_area.replace(")", "]")

        data_cordinate_centru = kordinatescentru.replace("LatLng(", "")
        data_cordinate_centru = data_cordinate_centru.replace(")", "")


        # print(data_cordinate_centru)
        

        forms = GrupuViveirusForm(request.POST,request.FILES)
        if forms.is_valid():
            instance = forms.save(commit=False)

            instance.kordinate_area = data_cordinate_area
            instance.kordinate_centru = data_cordinate_centru
            instance.user_created = User.objects.get(id=request.user.id)
            instance.date_created = date.today()
            # instance.user_update = User.objects.get(id=request.user.id)
            instance.save()
            messages.success(request,"Dados Rejistu  ho Susessu..!")
            return redirect('mapa:grupuviveirus')


    if request.GET.__contains__('kordinate') :
        kordinate = str(request.GET['kordinate'])
        print("kordinate : " + kordinate)
    else :
        kordinate = "mamuk"



    grupuviveirusform = GrupuViveirusForm()







    context = {
        "asaun" : "input",
        "pajina_grupuviveirus" : "active",
        "kordinate" : kordinate,
        # "dokumentu" : dokumentu,
        # "pajina_titulu" : "Rejistu Dokumentu",
        # "button" : "Rejistu",
        "forms" : grupuviveirusform,
    }
    return render(request, 'mapa/grupuviveirus/input.html',context)



@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def editgrupuviveirus(request,id):

    grupuviveirus = GrupuViveirus.objects.get(id=id)
    grupuviveirus2 = GrupuViveirus.objects.filter(id=id)


    kordinatekoa = ""



    if request.method == 'POST':

        kordinatesarea = request.POST['kordinate_area']
        kordinatescentru = request.POST['kordinate_centru']

        data_cordinate_area = kordinatesarea.replace("LatLng(", "[")
        data_cordinate_area = data_cordinate_area.replace(")", "]")

        data_cordinate_centru = kordinatescentru.replace("LatLng(", "")
        data_cordinate_centru = data_cordinate_centru.replace(")", "")

        forms = GrupuViveirusForm(request.POST,request.FILES,instance=grupuviveirus)
        if forms.is_valid():

            instance = forms.save(commit=False)
            instance.user_created = User.objects.get(id=request.user.id)
            instance.date_created = date.today()


            if kordinatescentru == "":

                print("kordinate area la atualiza")

            else : 
                instance.kordinate_centru = data_cordinate_centru   
                if kordinatesarea == "":
                    print("kordinate centeru la atualiza")
                else : 
                    print(data_cordinate_area)
                    print("no")
                    print(data_cordinate_centru)


                    instance.kordinate_area = data_cordinate_area
                    instance.kordinate_centru = data_cordinate_centru

            # instance.user_update = User.objects.get(id=request.user.id)
            messages.success(request,"Dados Update  Susessu..!")
            instance.save()
            return redirect('mapa:grupuviveirus')
    grupuviveirusform = GrupuViveirusForm(instance = grupuviveirus)

    if request.GET.__contains__('kordinate') :
        kordinate = str(request.GET['kordinate'])
        print("kordinate : " + kordinate)
    else :
        kordinate = "mamuk"

    context = {
        "asaun" : "edit",
        "pajina_grupuviveirus" : "active",
        "grupuviveirus" : grupuviveirus,
        "kordinate" : kordinate,
        "kordinate_area" : grupuviveirus.kordinate_area,
        "naran_grupu" : grupuviveirus.naran,
        "kordinate_centru" :  grupuviveirus.kordinate_centru, 
        # "pajina_titulu" : "Rejistu Dokumentu",
        # "button" : "Rejistu",
        "forms" : grupuviveirusform,
    }
    return render(request, 'mapa/grupuviveirus/update.html',context)




@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def deletegrupuviveirus(request,id):
    grupubambu = GrupuViveirus.objects.get(id=id)
    grupubambu.delete()
    messages.success(request,"Dados Apaga  Susessu..!")
    return redirect('mapa:grupuviveirus')





@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def detallugrupuviveirus(request,id):

    dadosraix = GrupuViveirus.objects.filter(id=id)
  


    grupuviveirus = GrupuViveirus.objects.get(id=id)
    grupuviveirus2 = GrupuViveirus.objects.filter(id=id)

    context = {
        "pajina_grupuviveirus" : "active",
        "grupuviveirus" : grupuviveirus,
        "naran_grupu" : grupuviveirus.naran,
        "kordinate_area" : grupuviveirus.kordinate_area,
        "kordinate_centru" :  grupuviveirus.kordinate_centru, 
        "grupuviveirus2" : grupuviveirus2,

    }
    return render(request, 'mapa/grupuviveirus/detallu.html',context)


from django import forms 
from django.forms import ModelForm 

from .models import *


from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Submit, Row, Column, Button, HTML,Field,Div
from crispy_forms.bootstrap import TabHolder,Tab
# class DetailluNotisiaForm(forms.ModelForm):
# 	class Meta:
# 		model = Detaillu_Notisia 
# 		fields = ['sub_kategoria']

# class HakerekNotisiaKategoriaJornalForm(forms.ModelForm):
# 	class Meta:
# 		model = Notisia
# 		fields = ['titulu','sub_titulu','body','kategoria']


# class EditorNotisiaForm(forms.ModelForm):
# 	class Meta:
# 		model = Notisia
# 		fields = ['titulu','sub_titulu','body']

# 		widgets = {
#         'body': forms.Textarea(attrs={
#             'class':'form-control django-ckeditor-widget ckeditor',
#             'id':'form-control',
#             'spellcheck':'False'}),
#     }


# class uploadImagenNotisiaForm(forms.ModelForm):
# 	imagen_sub = forms.ImageField(required=True)
# 	class Meta:
# 		model = Imagen
# 		fields = ['imagen_sub']

# class FormFileUpload(forms.ModelForm):
# 	class Meta:
# 		model = FileUpload
# 		fields = ['deskrisaun','file_upload']

# class FormDokumentu(forms.ModelForm):
# 	class Meta:
# 		model = Dokumentu
# 		fields = ['naran','data_asinatura','aprovadu_cm','aprovadu_pm','resolusaun','tipu','lingua','nasaun','localizasaun','kategoria','date_hahu','date_remata','validade']

# 		widgets = {
# 			'data_asinatura': forms.DateInput(attrs={'type':'date'}),
# 			'date_hahu': forms.DateInput(attrs={'type':'date'}),
# 			'date_remata': forms.DateInput(attrs={'type':'date'})
		# }

class GrupuBambuForm(forms.ModelForm):
	# descriptiond = forms.CharField(label="Observasaun", widget=forms.Textarea(attrs={"rows":2}), required=False)

	class Meta:
		model = GrupuBambu
		fields = ['naran','suku','deskrisaun','imagen','kontaktu','naran_kordenador']


        

	def __init__(self, *args, **kwargs):
		super(GrupuBambuForm, self).__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.fields['suku'].choices=[(item.pk, (str(item.naran) + str(" / Postu  ") + str(item.postu) + str(" / Munisípiu ") + str(item.postu.munisipiu) )) for item in Suku.objects.all()]
		self.helper.form_id = 'form_bambu'
		self.helper.layout = Layout(
			





			Row(
			Column('naran', css_class='form-group col-md-12 mb-0'),
			Column('naran_kordenador', css_class='form-group col-md-12 mb-0'),
			Column('kontaktu', css_class='form-group col-md-12 mb-0'),
			Column('imagen', css_class='form-group col-md-12 mb-0'),
			Column(Field('suku', css_class="form-select"), css_class='form-group col-md-12 mb-0'),
			# Column('kordinate_centru', css_class='form-group col-md-12 mb-0'),
			# Column('kordinate_area', css_class='form-group col-md-12 mb-0'),

				
			HTML(""" 

			{% if asaun  == 'edit' %}

			<input type='hidden' value='{% if kordinate == 'mamuk' %}  {{kordinate_centru}}  {% else %} {{kordinate}} {% endif %} ' id="kordinate_centru" name='kordinate_centru'>	<input type='hidden'  value ='{{kordinate_area}}' id = 'kordinate_area' name='kordinate_area'>
			{% else %}
			<input type='hidden' value='{% if kordinate != 'mamuk' %}  {{kordinate}} {% endif %}' id="kordinate_centru"  name='kordinate_centru'>	<input type='hidden'  id = 'kordinate_area' name='kordinate_area'>
			{% endif %}
	
	<br>
			 """),


			Column('deskrisaun', css_class='form-group col-md-12 mb-0'),
			# Column('kordinate_centru', css_class='form-group col-md-4 mb-0'),
			css_class='form-row'
			),

				
			HTML(""" 

		
			
			<br>
				<div class='float-right'>



			<button  id = 'bambuinput' class="btn btn-sm btn-info" type="submit"><i class="fa fa-save"></i> {% if asaun  == 'edit' %} Atualiza {% else %} Rejistu {% endif %}
				</button>

					<a class="btn btn-sm btn-warning" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</a>


			
				
				</div>
				
				""")
		)








class ImportasaunBambuForm(forms.ModelForm):
	# descriptiond = forms.CharField(label="Observasaun", widget=forms.Textarea(attrs={"rows":2}), required=False)
	data_importasaun = forms.DateField(label="Data ",widget=forms.TextInput(attrs={'type': 'date'}))
	class Meta:
		model = ImportasaunBambu
		fields = ['data_importasaun','kuantidade','deskrisaun']
	def __init__(self, *args, **kwargs):
		super(ImportasaunBambuForm, self).__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.helper.form_id = 'form_bambu'
		self.helper.layout = Layout(
			
		Row(

			Column('kuantidade', css_class='form-group col-md-6 mb-0'),
			Column(Field('data_importasaun', css_class="form-select"), css_class='form-group col-md-6 mb-0'),
			Column('deskrisaun', css_class='form-group col-md-12 mb-0'),
			css_class='row'),



			HTML(""" 
			<br>
				<div class='float-right'>
			<button  id = 'bambuinput' class="btn btn-sm btn-info" type="submit"><i class="fa fa-save"></i> {% if asaun  == 'edit' %} Atualiza {% else %} Rejistu {% endif %}
				</button>

					<a class="btn btn-sm btn-warning" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</a>
				</div>
				
				""")
		)
		






class GrupuViveirusForm(forms.ModelForm):
	# descriptiond = forms.CharField(label="Observasaun", widget=forms.Textarea(attrs={"rows":2}), required=False)

	class Meta:
		model = GrupuViveirus
		fields = ['naran','suku','deskrisaun','imagen','kontaktu','naran_kordenador']


        

	def __init__(self, *args, **kwargs):
		super(GrupuViveirusForm, self).__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.fields['suku'].choices=[(item.pk, (str(item.naran) + str(" / Postu  ") + str(item.postu) + str(" / Munisípiu ") + str(item.postu.munisipiu) )) for item in Suku.objects.all()]
		self.helper.form_id = 'form_viveirus'
		self.helper.layout = Layout(
			





			Row(
			Column('naran', css_class='form-group col-md-12 mb-0'),
			Column('naran_kordenador', css_class='form-group col-md-12 mb-0'),
			Column('kontaktu', css_class='form-group col-md-12 mb-0'),
			Column('imagen', css_class='form-group col-md-12 mb-0'),
			Column(Field('suku', css_class="form-select"), css_class='form-group col-md-12 mb-0'),
			# Column('kordinate_centru', css_class='form-group col-md-12 mb-0'),
			# Column('kordinate_area', css_class='form-group col-md-12 mb-0'),

				
			HTML(""" 

			{% if asaun  == 'edit' %}

			<input type='hidden' value='{% if kordinate == 'mamuk' %}  {{kordinate_centru}}  {% else %} {{kordinate}} {% endif %} ' id="kordinate_centru" name='kordinate_centru'>	<input type='hidden'  value ='{{kordinate_area}}' id = 'kordinate_area' name='kordinate_area'>
			{% else %}
			<input type='hidden' value='{% if kordinate != 'mamuk' %}  {{kordinate}} {% endif %}' id="kordinate_centru"  name='kordinate_centru'>	<input type='hidden'  id = 'kordinate_area' name='kordinate_area'>
			{% endif %}
	
	<br>
			 """),


			Column('deskrisaun', css_class='form-group col-md-12 mb-0'),
			# Column('kordinate_centru', css_class='form-group col-md-4 mb-0'),
			css_class='form-row'
			),

				
			HTML(""" 

		
			
			<br>
				<div class='float-right'>



			<button  id = 'bambuinput' class="btn btn-sm btn-info" type="submit"><i class="fa fa-save"></i> {% if asaun  == 'edit' %} Atualiza {% else %} Rejistu {% endif %}
				</button>

					<a class="btn btn-sm btn-warning" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</a>


			
				
				</div>
				
				""")
		)







class AreaBambuForm(forms.ModelForm):
	# descriptiond = forms.CharField(label="Observasaun", widget=forms.Textarea(attrs={"rows":2}), required=False)

	class Meta:
		model = AreaBambu
		fields = ['naran','suku','deskrisaun','imagen','kontaktu','naran_kordenador','kordinate_area']


        

	def __init__(self, *args, **kwargs):
		super(AreaBambuForm, self).__init__(*args, **kwargs)
		self.helper = FormHelper()
		self.helper.form_method = 'post'
		self.fields['suku'].choices=[(item.pk, (str(item.naran) + str(" / Postu  ") + str(item.postu) + str(" / Munisípiu ") + str(item.postu.munisipiu) )) for item in Suku.objects.all()]
		self.helper.form_id = 'form_viveirus'
		self.helper.layout = Layout(
			





			Row(
			# Column('kordinate_area', css_class='form-group col-md-12 mb-0'),
			Column('naran', css_class='form-group col-md-12 mb-0'),
			Column('naran_kordenador', css_class='form-group col-md-12 mb-0'),
			Column('kontaktu', css_class='form-group col-md-12 mb-0'),
			Column('imagen', css_class='form-group col-md-12 mb-0'),
			Column(Field('suku', css_class="form-select"), css_class='form-group col-md-12 mb-0'),
			# Column('kordinate_centru', css_class='form-group col-md-12 mb-0'),


				
				
			HTML(""" 

			{% if asaun  == 'edit' %}

			<input type='hidden' value=' {{kordinate_centru}}' id="kordinate_centru" name='kordinate_centru'>	<input type='hidden'  value ='{% if kordinate == 'mamuk' %}  {{kordinate_area}}  {% else %} {{kordinate}} {% endif %}' id = 'kordinate_area' name='kordinate_area'>
			{% else %}
			<input type='hidden' value='' id="kordinate_centru"  name='kordinate_centru'>	<input type='hidden'  id = 'kordinate_area' value='{% if kordinate != 'mamuk' %}  {{kordinate}} {% endif %}' name='kordinate_area'>
			{% endif %}
	
	<br>
			 """),


			Column('deskrisaun', css_class='form-group col-md-12 mb-0'),
			# Column('kordinate_centru', css_class='form-group col-md-4 mb-0'),
			css_class='form-row'
			),

				
			HTML(""" 

		
			
			<br>
				<div class='float-right'>



			<button  id = 'bambuinput' class="btn btn-sm btn-info" type="submit"><i class="fa fa-save"></i> {% if asaun  == 'edit' %} Atualiza {% else %} Rejistu {% endif %}
				</button>

					<a class="btn btn-sm btn-warning" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</a>


			
				
				</div>
				
				""")
		)



# class GrupuBambuForm(forms.ModelForm):

# 	class Meta:
# 		model = GrupuBambu
# 		fields = ['naran','suku','deskrisaun']

# 	def __init__(self, *args, **kwargs):
# 		super(GrupuBambuForm, self).__init__(*args, **kwargs)
# 		self.helper = FormHelper()
# 		#     self.fields['aldeia'].choices=[
# 		#  (item.id, (str(item.name) )) for item in Aldeia.objects.filter(Q(village__id= site_id))]
# 		self.helper.form_method = 'post'
# 		self.helper.form_id = 'grupubambu'
        
#         # self.fields['aldeia'].choices=[(item.pk, (" Aldeia " + str(item.name) +" / Suku  " + str(item.village) + " / Postu "+ str(item.village.administrativepost) + " / Munisipiu " + str(item.village.administrativepost.municipality))) for item in Aldeia.objects.all()]


# 		self.helper.layout = Layout(

# 				Row(
# 				Column('naran', css_class='form-group col-md-4 mb-0'),
# 				Column('suku', css_class='form-group col-md-4 mb-0'),
# 				# Column('kordinate_centru', css_class='form-group col-md-4 mb-0'),
# 				css_class='form-row'
# 				),

# 				Row(
# 				# Column('kordinate_area', css_class='form-group col-md-4 mb-0'),
# 				Column('deskrisaun', css_class='form-group col-md-4 mb-0'),
# 				css_class='form-row'
# 				),

# 					HTML("""
						
# 							<a href='#'    id = '' class="btn btn-info" ><i class="fa fa-save"></i>  Rai </a>
# 					<a class="btn btn-sm btn-labeled btn-secondary" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</a>
			
# 				"""),
# 		)	






# class FormKomentariu(forms.ModelForm):
# 	class Meta:
# 		model = Komentariu
# 		fields = ['komentariu']





# class DateInput(forms.DateInput):
# 	input_type = 'date'
# class EdisaunNotisiaForm(forms.ModelForm):
# 	class Meta:
# 		model = Edisaun 
# 		fields = ['titulu','kategoria_edisaun','data','file_pdf']

# 		widgets = {
# 			'data': DateInput(),
# 		}


# class UploadFilePdf(forms.ModelForm):
# 	class Meta:
# 		model = Edisaun
# 		fields = ['file_pdf']



from django.shortcuts import render,redirect
from django.contrib.auth.decorators import login_required
# from population.models import Population,DetailFamily,Family,Religion,Profession,Citizen,Aldeia,Village,User,Migration,Death,Migrationout,Temporary,ChangeFamily
# from population.utils import getnewidp,getnewidf
# from population.forms import Family_form,Family_form,FamilyPosition,Population_form,DetailFamily_form,CustumDetailFamily_form,Death_form,Migration_form,Migrationout_form,Changefamily_form
from django.views.decorators.csrf import csrf_exempt
import json
from django.utils import timezone

from django.core.paginator import Paginator

# from mapa.forms import *
# from custom.utils import getnewid, getjustnewid, hash_md5, getlastid
from django.db.models import Count
from django.contrib import messages
from django.shortcuts import get_object_or_404
from django.db.models import Q
from datetime import date
from django.http import JsonResponse
# from employee.models import *
# from datetime import datetime, timedelta
# from vizitor.forms import CustomAuthenticationForm
from django.contrib.auth.views import LoginView
from django.contrib.auth import authenticate, login, logout

from django.contrib.auth.decorators import login_required
from geoalgo.algo_tree import calc
from mapa.models import *
from mapa.forms import *
from django.contrib.auth.models import User
from main.decorators import login_ona, seidauk_login, allowed_users



@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def areabambu(request):

    buka = False;
    bukatitle = "mamuk"
    
    if request.GET.__contains__('page') :
        page_num = request.GET.get('page')
    else:
        page_num = 1
    if request.GET.__contains__('pesquiza'):
        buka = True
        paginator = Paginator(AreaBambu.objects.order_by('-id').filter(naran__icontains=request.GET['pesquiza']), 1)
    else:
        paginator = Paginator(AreaBambu.objects.order_by('-id'), 10)

    page_range = []
    for i in range(paginator.num_pages):
        page_range.append(i+1)
        data_AreaBambu = paginator.page(page_num)

        page_num_int = int(page_num)

    if buka :
        bukatitle = "Rezultadu Pesquiza husi <i>' (" + request.GET['pesquiza'] + ") '</i>"

    context = {
        "pajina_areabambu" : "active",
        "areabambu" : data_AreaBambu,
        'bukatitle' : bukatitle,
        'page_range' : page_range,
        'current_page' : page_num_int,
    }
    return render(request, 'mapa/areabambu/lista.html',context)




@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def inputareabambu(request):
    kordinate = "mamuk"
    # kordinate_centru = "mamuk"

    if request.method == 'POST':

        kordinatesarea = request.POST['kordinate_area']
        kordinatescentru = request.POST['kordinate_centru']

        data_cordinate_area = kordinatesarea.replace("LatLng(", "[")
        data_cordinate_area = data_cordinate_area.replace(")", "]")

        data_cordinate_centru = kordinatescentru.replace("LatLng(", "")
        data_cordinate_centru = data_cordinate_centru.replace(")", "")


        print(data_cordinate_centru)
        

        forms = AreaBambuForm(request.POST,request.FILES)
        if forms.is_valid():
            instance = forms.save(commit=False)

            instance.kordinate_area = data_cordinate_area
            instance.kordinate_centru = data_cordinate_centru
            instance.user_created = User.objects.get(id=request.user.id)
            instance.date_created = date.today()
            # instance.user_update = User.objects.get(id=request.user.id)
            instance.save()
            messages.success(request,"Dados Rejistu  ho Susessu..!")
            return redirect('mapa:areabambu')

    if request.GET.__contains__('kordinate') :
        kordinate = str(request.GET['kordinate'])
        # kordinate_centru = str(request.GET['kordinate_centru'])
        print("kordinate area : " + kordinate)
        # print("kordinate centru : " + kordinate_centru)
    else :
        kordinate = "mamuk"


    areabambuform = AreaBambuForm()


    context = {
        "asaun" : "input",
        "pajina_areabambu" : "active",
        # "kordinate_area" : kordinate_area,
        "kordinate" : kordinate,
        # "kordinate_centru" : kordinate_centru,

        # "kordinate_centru" : kordinate_centru,
        # "dokumentu" : dokumentu,
        # "pajina_titulu" : "Rejistu Dokumentu",
        # "button" : "Rejistu",
        "forms" : areabambuform,
    }
    return render(request, 'mapa/areabambu/input.html',context)



@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def editareabambu(request,id):

    areabambu = AreaBambu.objects.get(id=id)
    areabambu2 = AreaBambu.objects.filter(id=id)


    kordinatekoa = ""

    for dados in areabambu2.iterator():
        
        kordinates = dados.kordinate_area
        kordinates = kordinates.replace("[", "")
        kordinates = kordinates.replace("]", "")
        kordinates = kordinates.replace(",-", "=-")
        kordinates = kordinates.replace(", -", "=-")
        kordinatekoa = kordinates.split("=")

    # print(kordinatekoa);

    if request.method == 'POST':

        kordinatesarea = request.POST['kordinate_area']
        kordinatescentru = request.POST['kordinate_centru']

        data_cordinate_area = kordinatesarea.replace("LatLng(", "[")
        data_cordinate_area = data_cordinate_area.replace(")", "]")

        data_cordinate_centru = kordinatescentru.replace("LatLng(", "")
        data_cordinate_centru = data_cordinate_centru.replace(")", "")

        forms = AreaBambuForm(request.POST,request.FILES,instance=areabambu, )
        if forms.is_valid():

            instance = forms.save(commit=False)
            instance.user_created = User.objects.get(id=request.user.id)
            instance.date_created = date.today()


            if kordinatesarea == "":
                print("kordinate area la atualiza")

            else : 
                
                if kordinatescentru == "":
                    print("kordinate centeru la atualiza")
                else : 
                    print(data_cordinate_area)
                    print("no")
                    print(data_cordinate_centru)


                    instance.kordinate_area = data_cordinate_area
                    instance.kordinate_centru = data_cordinate_centru

            # instance.user_update = User.objects.get(id=request.user.id)
            messages.success(request,"Dados Update  Susessu..!")
            instance.save()
            return redirect('mapa:areabambu')


    if request.GET.__contains__('kordinate') :
        kordinate = str(request.GET['kordinate'])
        # kordinate_centru = str(request.GET['kordinate_centru'])
        print("kordinate area : " + kordinate)
        # print("kordinate centru : " + kordinate_centru)
    else :
        kordinate = "mamuk"


    areabambuform = AreaBambuForm(instance = areabambu)

    context = {
        "asaun" : "edit",
        "pajina_areabambu" : "active",
        "areabambu" : areabambu,
        "kordinate_area" : areabambu.kordinate_area,
        "kordinate" : kordinate,
        "naran_grupu"  : areabambu.naran,
        "kordinate_centru" :  areabambu.kordinate_centru, 
        # "pajina_titulu" : "Rejistu Dokumentu",
        # "button" : "Rejistu",
        "forms" : areabambuform,
    }
    return render(request, 'mapa/areabambu/update.html',context)




@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def deleteareabambu(request,id):
    areabambu = AreaBambu.objects.get(id=id)
    areabambu.delete()
    messages.success(request,"Dados Apaga  Susessu..!")
    return redirect('mapa:areabambu')





@login_ona
@allowed_users(allowed_roles=['adminbambu'])
def detalluareabambu(request,id):
    test = ""
    import math
    dadosraix = AreaBambu.objects.filter(id=id)
  
    km2 = ""
    R=6371000  
    data_distance = []
    for dados in dadosraix.iterator():

        kordinates = dados.kordinate_area
        kordinates = kordinates.replace("[", "")
        kordinates = kordinates.replace("]", "")
        kordinates = kordinates.replace(",-", "=-")
        kordinates = kordinates.replace(", -", "=-")
        kordinatekoa = kordinates.split("=") 


        # kalkula kordinate husi poin ida ba ida
        meter = 0
        totalkor = len(kordinatekoa)
        kor1 = 0
        for i in   range(totalkor) :
            lat2 = i + 1

            if lat2 < totalkor :
                ko1 = kordinatekoa[i].split(",") 
                ko2 =  kordinatekoa[lat2].split(",") 

                # lat1 = ko1[0]
                # lat2 = ko2[0]


                # lon1 = ko1[1]
                # lon2 = ko2[1]
                phi_1=math.radians(float(ko1[0]))
                phi_2=math.radians(float(ko2[0]))
                delta_phi=math.radians(float(ko2[0])-float(ko1[0]))
                delta_lambda=math.radians(float(ko2[1])-float(ko1[1]))
                a=math.sin(delta_phi/2.0)**2+\
                math.cos(phi_1)*math.cos(phi_2)*\
                math.sin(delta_lambda/2.0)**2
                c=2*math.atan2(math.sqrt(a),math.sqrt(1-a))
                meters=R*c
                meter = meter+meters
                meter = round(meter)
                data_distance.append({"kor1": kordinatekoa[i], "kor2": kordinatekoa[lat2], "distancia" : meter, "husi": i+1 ,"ba": lat2+1})

                # print(kordinatekoa[i] + "ho" + kordinatekoa[lat2]) 
            else :
                # print(kordinatekoa[i]+" ho "+ kordinatekoa[0])
                ko1 = kordinatekoa[i].split(",") 
                ko2 =  kordinatekoa[0].split(",") 

                phi_1=math.radians(float(ko1[0]))
                phi_2=math.radians(float(ko2[0]))
                delta_phi=math.radians(float(ko2[0])-float(ko1[0]))
                delta_lambda=math.radians(float(ko2[1])-float(ko1[1]))
                a=math.sin(delta_phi/2.0)**2+\
                math.cos(phi_1)*math.cos(phi_2)*\
                math.sin(delta_lambda/2.0)**2
                c=2*math.atan2(math.sqrt(a),math.sqrt(1-a))
                meters=R*c
                meter = meter+meters
                meter = round(meter)
                data_distance.append({"kor1": kordinatekoa[i], "kor2": kordinatekoa[0], "distancia" : meter, "husi": i+1 ,"ba": "zero"})


        test = calc(kordinatekoa)


        AreaBambu.objects.filter(pk=id).update(hectar=test)


    areabambu = AreaBambu.objects.get(id=id)
    areabambu2 = AreaBambu.objects.filter(id=id)




    print(data_distance)
    areabambuform = AreaBambuForm(instance = areabambu)

    context = {
        "pajina_dokumentu" : "active",
        "data_distance" : data_distance,
        "areabambu2" : areabambu2,
        "areabambu" : areabambu,
        "kordinate_area" : areabambu.kordinate_area,
        "kordinate_centru" :  areabambu.kordinate_centru, 
        "km2" : test[0],
        "hectar" : test[1],
        "pajina_areabambu" : "active",
        # "pajina_titulu" : "Rejistu Dokumentu",
        # "button" : "Rejistu",
        "forms" : areabambuform,
    }
    return render(request, 'mapa/areabambu/detallu.html',context)


from django.contrib import admin
from dokumentu.models import *
# Register your models here.


admin.site.register(Lingua)
admin.site.register(Rejiaun)
admin.site.register(Nasaun)
admin.site.register(Lokalizasaun)
admin.site.register(KategoriaDoc)
admin.site.register(Dokumentu)
admin.site.register(FileUpload)
admin.site.register(Komentariu)


from django.db import models
from jeral.models import *
from django.contrib.auth.models import User

from ckeditor.fields import RichTextField


# Create your models here.



# TIPO = (
#         ("copia", "copia"),
#         ("original", "original"),
#         ("copia/original", "copia/original"),
#         )


# APROVE_TYPE = (
#         ("sim", "sim"),
#         ("nao", "nao"),
#         ("nao/necesario", "nao/necesario"),
#         )


class GrupuBambu(models.Model):
    naran 	= models.CharField(max_length=255,null=False, blank=False,verbose_name = "Naran Grupu")
    naran_kordenador 	= models.CharField(max_length=255,null=True, blank=True,verbose_name = "Naran Kordenador")
    suku = models.ForeignKey(Suku, on_delete = models.CASCADE, verbose_name = "Hili Suku")
    kordinate_centru = models.CharField(max_length=255,null=False, blank=False)
    kordinate_area= models.TextField(null=True, blank=True)
    deskrisaun = RichTextField(max_length=255,null=False, blank=False)
    date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
    imagen		= models.ImageField(upload_to='grupubambu/', default='grupubambu/default.png', null=True, blank=True)
    kontaktu 	= models.CharField(max_length=255,null=True, blank=True)
    user_created = models.ForeignKey(User, on_delete = models.CASCADE,null=True, blank=True, verbose_name = "Hili User")
    hashed = models.TextField(null=False, blank=False)

    def __str__(self):
        return "{}. {} - {}".format(self.id, self.naran, self.deskrisaun)
        return template.format(self)
    class Meta :
        verbose_name_plural = "Grupu Bambu"


class ImportasaunBambu(models.Model):
    grupubambu = models.ForeignKey(GrupuBambu, on_delete = models.CASCADE, verbose_name = "Hili Grupu Bambu")
    data_importasaun = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
    kuantidade = models.CharField(verbose_name="Quantidade",null=True, blank=True, max_length=200)
    deskrisaun = RichTextField(max_length=255,null=False, blank=False, verbose_name="Deskrisaun")
    date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
    user_created = models.ForeignKey(User, on_delete = models.CASCADE,null=True, blank=True, verbose_name = "Hili User")
    hashed = models.TextField(null=True, blank=True)


    def __str__(self):
        return "{}. {} - {}".format(self.id, self.data_importasaun, self.deskrisaun)
        return template.format(self)
    class Meta :
        verbose_name_plural = "Grupu Bambu"




class GrupuViveirus(models.Model):
    naran 	= models.CharField(max_length=255,null=False, blank=False,verbose_name = "Naran Grupu")
    naran_kordenador 	= models.CharField(max_length=255,null=True, blank=True,verbose_name = "Naran Kordenador")
    suku = models.ForeignKey(Suku, on_delete = models.CASCADE, verbose_name = "Hili Suku")
    kordinate_centru = models.CharField(max_length=255,null=False, blank=False)
    kordinate_area= models.TextField(null=True, blank=True)
    deskrisaun = RichTextField(max_length=255,null=False, blank=False)
    date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
    imagen		= models.ImageField(upload_to='grupuviveirus/', default='grupuviveirus/default.png', null=True, blank=True)
    kontaktu 	= models.CharField(max_length=255,null=True, blank=True)
    user_created = models.CharField(max_length=255)
    user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Kria")
    hashed = models.TextField(null=False, blank=False)

    def __str__(self):
        return "{}. {} - {}".format(self.id, self.naran, self.deskrisaun)
        return template.format(self)
    class Meta :
        verbose_name_plural = "Grupu Viveirus"




class AreaBambu(models.Model):
    naran 	= models.CharField(max_length=255,null=False, blank=False)
    naran_kordenador 	= models.CharField(max_length=255,null=True, blank=True,verbose_name = "Naran Kordenador")
    suku = models.ForeignKey(Suku, on_delete = models.CASCADE, verbose_name = "Hili Suku")
    kordinate_centru = models.CharField(max_length=255,null=False, blank=False)
    hectar 	= models.CharField(max_length=255,null=True, blank=True,verbose_name = "Hectar")
    kordinate_area= models.TextField(null=False, blank=False)
    imagen		= models.ImageField(upload_to='areabambu/', default='areabambu/default.png', null=True, blank=True)
    kontaktu 	= models.CharField(max_length=255,null=True, blank=True)
    deskrisaun = RichTextField(max_length=255,null=False, blank=False)
    date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
    kor = models.CharField(max_length=255,blank=True, null=True)
    user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Kria")
    hashed = models.TextField(null=False, blank=False)

    def __str__(self):
        return "{}. {} - {}".format(self.id, self.naran, self.deskrisaun)
        return template.format(self)
    class Meta :
        verbose_name_plural = "Area Bambu"


# class Rejiaun(models.Model):
#     rejiaun 	= models.CharField(max_length=255,null=False, blank=False)
#     user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Ne'ebe Kria")
#     date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
#     user_update = models.CharField(max_length=255)

#     def __str__(self):
#         return "{}. {}".format(self.id, self.rejiaun, )
#     class Meta :
#         verbose_name_plural = "Relijiaun"



# class Nasaun(models.Model):
#     nasaun 	= models.CharField(max_length=255,null=False, blank=False)
#     rejiaun			= models.ForeignKey(Rejiaun, on_delete=models.CASCADE, null=False, blank=False)
#     user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Ne'ebe Kria")
#     date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
#     user_update = models.CharField(max_length=255)

#     def __str__(self):
#         return "{}. {} - {}".format(self.id, self.nasaun, self.rejiaun.rejiaun)
#     class Meta :
#         verbose_name_plural = "Nasaun"





# class Lokalizasaun(models.Model):
#     lokalizasaun 	= models.CharField(max_length=255,null=False, blank=False)
#     deskrisaun 	= models.TextField(max_length=255,null=False, blank=False)
#     user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Ne'ebe Kria")
#     date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
#     user_update = models.CharField(max_length=255)
#     def __str__(self):
#         return "{}. {} - {}".format(self.id, self.lokalizasaun, self.deskrisaun)
#     class Meta :
#         verbose_name_plural ="Lokalizasaun"



# class KategoriaDoc(models.Model):
#     kategoria 	= models.CharField(max_length=255,null=False, blank=False)
#     user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Ne'ebe Kria")
#     date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
#     user_update = models.CharField(max_length=255)
#     def __str__(self):
#         return "{}. {}".format(self.id, self.kategoria)
#     class Meta :
#         verbose_name_plural ="Kategoria Dokumentu"


# class  Dokumentu(models.Model):
#     naran 	= models.TextField(null=False, blank=False)
#     data_asinatura			= models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
#     aprovadu_cm = models.CharField(max_length=50,choices=APROVE_TYPE,verbose_name='Aprovadu CM : ',null = True, blank = True)
#     aprovadu_pm = models.CharField(max_length=50,choices=APROVE_TYPE,verbose_name='Aprovadu PM : ',null = True, blank = True)
#     resolusaun = models.TextField(default=False,null=True, blank = True, verbose_name = "Resolusaun")
#     tipu = models.CharField(max_length=50,choices=TIPO,verbose_name='Tipu Dokumentu : ',null = True, blank = True)
#     lingua = models.ForeignKey(Lingua, on_delete = models.CASCADE, verbose_name = "Lingua")
#     nasaun = models.ForeignKey(Nasaun, on_delete = models.CASCADE, verbose_name = "Nasaun")
#     localizasaun = models.ForeignKey(Lokalizasaun, on_delete = models.CASCADE, verbose_name = "Nasaun")
#     kategoria = models.ForeignKey(KategoriaDoc, on_delete = models.CASCADE, verbose_name = "Kategoria Dokumentu")
#     date_hahu= models.DateField(verbose_name="Data Hahu",null=True, blank=True)
#     date_remata = models.DateField(verbose_name="Data Remata",null=True, blank=True)
#     validade = models.TextField(verbose_name="Validade",null=True, blank=True)
#     user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Ne'ebe Kria",null=True, blank=True)
#     date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
#     user_update = models.CharField(max_length=255, null=True, blank = True)
#     status 	= models.BooleanField(default=False)
#     def __str__(self):
#         return "{}. {}".format(self.id, self.naran)
#     class Meta :
#         verbose_name_plural ="Dokumentu"



# class FileUpload(models.Model):
#     dokumentu = models.ForeignKey(Dokumentu, on_delete = models.CASCADE, verbose_name = "Dokumentu")
#     deskrisaun 	= models.TextField(null=True, blank=True)
#     file_upload = models.FileField(upload_to="file_dokumentu/",  null=False, blank=False)
#     date_upload = models.DateField(verbose_name="Data Upload",null=True, blank=True)
#     user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Ne'ebe Kria",null=True, blank=True)
#     date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
#     user_update = models.CharField(max_length=255)

#     def __str__(self):
#         return "{}. {} - {}".format(self.id,self.dokumentu, self.date_created)

#     class Meta :
#         verbose_name_plural ="File Upload"



# class  Komentariu(models.Model):
#     dokumentu = models.ForeignKey(Dokumentu, on_delete = models.CASCADE, verbose_name = "Dokumentu")
#     komentariu 		= models.TextField()
#     user_created = models.ForeignKey(User, on_delete = models.CASCADE, verbose_name = "User Ne'ebe Kria")
#     date_created = models.DateField(verbose_name="Data Rejistu",null=True, blank=True)
#     user_update = models.CharField(max_length=255)

#     def __str__(self):
#         return "{}. {} - {} - {} - {}".format(self.id, self.user_created, self.komentariu, self.user_created.first_name, self.dokumentu)

#     class Meta :
#         verbose_name_plural ="Komentario"



from django.contrib import admin
from django.urls import path, include

from django.conf import settings
from django.conf.urls.static import static
from mapa import  views


app_name = "mapa"

urlpatterns = [
    # path('admin/', admin.site.urls),
    path('grupubambu/', views.grupubambu, name='grupubambu'),
    path('input/grupubambu/', views.inputgrupubambu, name='inputgrupubambu'),
    path('edit/grupubambu/<int:id>', views.editgrupubambu, name='editgrupubambu'),
    path('delete/grupubambu/<int:id>', views.deletegrupubambu, name='deletegrupubambu'),
    path('delete/detallugrupubambu/<int:id>', views.detallugrupubambu, name='detallugrupubambu'),
    path('rejistu/importasaunbambu/<int:id>', views.rejistuimportasaunbambu, name='rejistuimportasaunbambu'),
    path('input/importasaunbambu/<int:id>', views.inputimportasaunbambu, name='inputimportasaunbambu'),
    path('edit/importasaungrupubambu/<int:id>', views.editimportasaungrupubambu, name='editimportasaungrupubambu'),
    path('delete/importasaungrupubambu/<int:id>', views.deleteimportasaungrupubambu, name='deleteimportasaungrupubambu'),






    
    path('grupuviveirus/', views.grupuviveirus, name='grupuviveirus'),
    path('input/grupuviveirus/', views.inputgrupuviveirus , name='inputgrupuviveirus'),
    path('edit/grupuviveirus/<int:id>', views.editgrupuviveirus, name='editgrupuviveirus'),
    path('delete/grupuviveirus/<int:id>', views.deletegrupuviveirus, name='deletegrupuviveirus'),
    path('delete/detallugrupuviveirus/<int:id>', views.detallugrupuviveirus, name='detallugrupuviveirus'),



    path('areabambu/', views.areabambu, name='areabambu'),
    path('input/areabambu/', views.inputareabambu , name='inputareabambu'),
    path('edit/areabambu/<int:id>', views.editareabambu, name='editareabambu'),
    path('delete/areabambu/<int:id>', views.deleteareabambu, name='deleteareabambu'),
    path('detallu/areabambu/<int:id>', views.detalluareabambu, name='detalluareabambu'),





    
    # path('atualizadokumentu/<int:pk>/', views.atualizadokumentu, name = 'atualizadokumentu'),
    # path('dokumentudetallu/<int:pk>/', views.dokumentudetallu, name = 'dokumentudetallu'),




    # path('dashboard/', views.dashboard, name='dashboard'),
]


urlpatterns += static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)
urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
